@@ -21,7 +21,6 @@ class PythonGraph(PythonCode):
             self.generate_graph(graph)
 
     def add_required_imports(self) -> List[str]:
-        self.add_line('import json')
         self.add_line('import random')
         self.add_line('import uuid')
         self.add_line('import numpy')
@@ -35,7 +34,7 @@ class PythonGraph(PythonCode):
         self.indent_right()
 
         if not graph.agents:
-            self.add_line('return json.dumps([])')
+            self.add_line('return []')
             self.indent_left()
             return
         
@@ -48,7 +47,7 @@ class PythonGraph(PythonCode):
             num_agents.append(f'_num_{agent.name}')
         self.add_line(f'num_agents = {" + ".join(num_agents)}')
 
-        self.add_line('random_id = uuid.uuid4().hex')
+        self.add_line('random_id = str(uuid.uuid4())[:4]')
         self.add_line('jids = [f"{i}_{random_id}@{domain}" for i in range(num_agents)]')
 
         self.add_line('agents = []')
@@ -71,5 +70,5 @@ class PythonGraph(PythonCode):
             self.add_line('next_agent_idx += 1')
             self.indent_left()
         
-        self.add_line('return json.dumps(agents)')
+        self.add_line('return agents')
         self.indent_left()
