@@ -33,7 +33,7 @@ def op_agent_PRM(state: State, name: str, category: str, args: List[str]) -> Non
     state.require(
         is_valid_name(name), 
         f'{name} is not a correct name.', 
-        f'Names can only contain alphanumeric signs, underscores and cannot be: {print_invalid_names()}.'
+        f'Names can only contain alphanumeric characters, underscores and cannot be: {print_invalid_names()}.'
     )
     
     match category, args:
@@ -87,7 +87,7 @@ def op_message_PRM(state: State, name: str, category: str) -> None:
     state.require(
         is_valid_name(name), 
         f'{name} is not a correct name.', 
-        f'Names can only contain alphanumeric signs, underscores and cannot be: {print_invalid_names()}.'
+        f'Names can only contain alphanumeric characters, underscores and cannot be: {print_invalid_names()}.'
     )
     
     match category:
